(function(FuseBox){FuseBox.$fuse$=FuseBox;
FuseBox.target = "browser";
var __process_env__ = {"NODE_ENV":"production"};
FuseBox.pkg("Lambda", {"@typed/common":"0.0.1-alpha.177+f2959b1"}, function(___scope___){
___scope___.file("source/index.js", function(exports, require, module, __filename, __dirname){

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
tslib_1.__exportStar(require("./always"), exports);
tslib_1.__exportStar(require("./apply"), exports);
tslib_1.__exportStar(require("./curry"), exports);
tslib_1.__exportStar(require("./curryObj"), exports);
tslib_1.__exportStar(require("./flip"), exports);
tslib_1.__exportStar(require("./id"), exports);
tslib_1.__exportStar(require("./memoize"), exports);
tslib_1.__exportStar(require("./noOp"), exports);
tslib_1.__exportStar(require("./pipe"), exports);
tslib_1.__exportStar(require("./tap"), exports);
tslib_1.__exportStar(require("./uncurry"), exports);
tslib_1.__exportStar(require("./types"), exports);
//# sourceMappingURL=index.js.map
});
___scope___.file("source/always.js", function(exports, require, module, __filename, __dirname){

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Create a function that always returns a given value
 * @param value :: a
 * @returns (...* -> a)
 */
exports.always = (value) => (..._) => value;
//# sourceMappingURL=always.js.map
});
___scope___.file("source/apply.js", function(exports, require, module, __filename, __dirname){

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const curry_1 = require("./curry");
/**
 * Call a function with a list of arguments
 * @param args List of arguments
 * @param fn Function to call
 */
exports.apply = curry_1.curry((args, fn) => fn(...args));
//# sourceMappingURL=apply.js.map
});
___scope___.file("source/curry.js", function(exports, require, module, __filename, __dirname){

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Allow a fixed length function to be partially applied.
 * @param f Function you'd like to curry
 */
exports.curry = (f) => {
    return curriedN(f.length, f, []);
};
function curriedN(arity, f, previousArgs) {
    if (arity < 2) {
        return f;
    }
    return (...args) => {
        const concatArgs = previousArgs.concat(args);
        return concatArgs.length >= arity ? f(...concatArgs) : curriedN(arity, f, concatArgs);
    };
}
//# sourceMappingURL=curry.js.map
});
___scope___.file("source/curryObj.js", function(exports, require, module, __filename, __dirname){

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ALL_PROPERTIES_NOT_FOUND = new Error('All Properties Not Found');
const defaultObject = Object.freeze(Object.create(null));
/**
 * Uses ES2015 Proxy to partially apply a function that takes in an options object
 * @param f :: Object a => (a -> b)
 */
exports.curryObj = (f) => _curryObj(f, defaultObject);
function _curryObj(f, previousObj) {
    return (x) => {
        const obj = proxyObject(Object.assign({}, previousObj, x));
        try {
            return f(obj);
        }
        catch (error) {
            if (error !== ALL_PROPERTIES_NOT_FOUND) {
                throw error;
            }
            return _curryObj(f, obj);
        }
    };
}
function proxyObject(a) {
    return new Proxy(a, {
        get(target, key) {
            if (!target.hasOwnProperty(key)) {
                throw ALL_PROPERTIES_NOT_FOUND;
            }
            return target[key];
        },
    });
}
//# sourceMappingURL=curryObj.js.map
});
___scope___.file("source/flip.js", function(exports, require, module, __filename, __dirname){

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const apply_1 = require("./apply");
/**
 * Reverse the first two arguments of a function
 * @param fn: (a -> b -> c)
 * @returns (b -> a -> c)
 */
exports.flip = (fn) => ((a, b, ...args) => apply_1.apply([b, a, ...args], fn));
//# sourceMappingURL=flip.js.map
});
___scope___.file("source/id.js", function(exports, require, module, __filename, __dirname){

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Identity function
 * @param value :: a - Value to return
 */
exports.id = (value) => value;
//# sourceMappingURL=id.js.map
});
___scope___.file("source/memoize.js", function(exports, require, module, __filename, __dirname){

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const common_1 = require("@typed/common");
/**
 * Memoize a function
 * @param f Function to memoize
 */
exports.memoize = (f) => {
    const cache = new Map();
    return (...args) => {
        const key = args.reduce((x, y) => x + common_1.toString(y), '');
        if (cache.has(key)) {
            return cache.get(key);
        }
        let result = f(...args);
        if (typeof result === 'function') {
            result = exports.memoize(result);
        }
        cache.set(key, result);
        return result;
    };
};
//# sourceMappingURL=memoize.js.map
});
___scope___.file("source/noOp.js", function(exports, require, module, __filename, __dirname){

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Function that does nothing
 */
exports.noOp = () => void 0;
//# sourceMappingURL=noOp.js.map
});
___scope___.file("source/pipe.js", function(exports, require, module, __filename, __dirname){

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/** Left-to-right composition for exactly two function */
exports.pipe2 = (f, g) => (x) => g(f(x));
/**
 * Generic Left-to-right composition
 */
exports.pipe = ((...fns) => fns.length > 1 ? fns.slice(1).reduce(exports.pipe2, fns[0]) : fns[0]);
//# sourceMappingURL=pipe.js.map
});
___scope___.file("source/tap.js", function(exports, require, module, __filename, __dirname){

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const curry_1 = require("./curry");
/**
 * Perform a side-effect with a value and return the given value.
 * @param fn :: (a -> *)
 * @param value :: a
 * @returns a
 */
exports.tap = curry_1.curry((fn, value) => {
    fn(value);
    return value;
});
//# sourceMappingURL=tap.js.map
});
___scope___.file("source/uncurry.js", function(exports, require, module, __filename, __dirname){

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Convert a function like (a -> b -> c -> d) into ((a, b, c) -> d)
 * @param fn :: Function to uncurry
 * @returns Function that accepts all arguments at once.
 */
function uncurry(f) {
    if (typeof f !== 'function' || f.length === 0) {
        return f;
    }
    // tslint:disable-next-line:only-arrow-functions
    return function () {
        let r = f;
        // tslint:disable-next-line:prefer-for-of
        for (let i = 0; i < arguments.length; i++) {
            r = r(arguments[i]);
        }
        return uncurry(r);
    };
}
exports.uncurry = uncurry;
//# sourceMappingURL=uncurry.js.map
});
___scope___.file("source/types.js", function(exports, require, module, __filename, __dirname){

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
//# sourceMappingURL=types.js.map
});
return ___scope___.entry = "source/index.js";
});
FuseBox.pkg("@typed/common@0.0.1-alpha.177+f2959b1", {}, function(___scope___){
___scope___.file("esm/index.js", function(exports, require, module, __filename, __dirname){

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
tslib_1.__exportStar(require("./addQueryParameters"), exports);
tslib_1.__exportStar(require("./clone"), exports);
tslib_1.__exportStar(require("./equals"), exports);
tslib_1.__exportStar(require("./executionEnvironment"), exports);
tslib_1.__exportStar(require("./functionName"), exports);
tslib_1.__exportStar(require("./includesWith"), exports);
tslib_1.__exportStar(require("./indexOf"), exports);
tslib_1.__exportStar(require("./mapArrayLike"), exports);
tslib_1.__exportStar(require("./mapObj"), exports);
tslib_1.__exportStar(require("./pathJoin"), exports);
tslib_1.__exportStar(require("./quote"), exports);
tslib_1.__exportStar(require("./toString"), exports);
tslib_1.__exportStar(require("./typeOf"), exports);
//# sourceMappingURL=index.js.map
//# sourceMappingURL=index.js.map
});
___scope___.file("esm/addQueryParameters.js", function(exports, require, module, __filename, __dirname){

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Append Query Parameters to a Url
 * @param url :: String
 * @param queryParams :: Record<string, string | undefined>
 * @returns string
 */
function addQueryParameters(url, queryParams) {
    if (queryParams === undefined) {
        return (queryParams) => __addQueryParameters(url, queryParams);
    }
    return __addQueryParameters(url, queryParams);
}
exports.addQueryParameters = addQueryParameters;
function __addQueryParameters(url, queryParams) {
    const params = Object.keys(queryParams)
        .sort()
        .map(queryParam(queryParams))
        .join('&');
    return encodeURI(`${url}${params ? `?${params}` : ''}`);
}
function queryParam(queryParams) {
    return (key) => {
        const value = queryParams[key];
        return value ? `${key}=${value}` : key;
    };
}
//# sourceMappingURL=addQueryParameters.js.map
//# sourceMappingURL=addQueryParameters.js.map
});
___scope___.file("esm/clone.js", function(exports, require, module, __filename, __dirname){

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const typeOf_1 = require("./typeOf");
function clone(value, refFrom, refTo, deep) {
    function copy(copiedValue) {
        const length = refFrom.length;
        let i = 0;
        for (; i < length; ++i) {
            if (value === refFrom[i]) {
                return refTo[i];
            }
        }
        refFrom[i + 1] = value;
        refTo[i + 1] = copiedValue;
        for (const key in value) {
            if (!value.hasOwnProperty(key)) {
                continue;
            }
            copiedValue[key] = deep ? clone(value[key], refFrom, refTo, true) : value[key];
        }
        return copiedValue;
    }
    switch (typeOf_1.typeOf(value)) {
        case 'Object':
            return copy({});
        case 'Array':
            return copy([]);
        case 'Date':
            return new Date(value.valueOf());
        case 'RegExp':
            return cloneRegexp(value);
        default:
            return value;
    }
}
exports.clone = clone;
function cloneRegexp(pattern) {
    return new RegExp(pattern.source, (pattern.global ? 'g' : '') +
        (pattern.ignoreCase ? 'i' : '') +
        (pattern.multiline ? 'm' : '') +
        (pattern.sticky ? 'y' : '') +
        (pattern.unicode ? 'u' : ''));
}
//# sourceMappingURL=clone.js.map
//# sourceMappingURL=clone.js.map
});
___scope___.file("esm/typeOf.js", function(exports, require, module, __filename, __dirname){

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function typeOf(value) {
    if (value === null) {
        return 'Null';
    }
    if (value === void 0) {
        return `Undefined`;
    }
    return Object.prototype.toString.call(value).slice(8, -1);
}
exports.typeOf = typeOf;
//# sourceMappingURL=typeOf.js.map
//# sourceMappingURL=typeOf.js.map
});
___scope___.file("esm/equals.js", function(exports, require, module, __filename, __dirname){

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const functionName_1 = require("./functionName");
const includesWith_1 = require("./includesWith");
const typeOf_1 = require("./typeOf");
function equals(a, b, stackA = [], stackB = []) {
    if (Object.is(a, b)) {
        return true;
    }
    const typeA = typeOf_1.typeOf(a);
    if (typeA !== typeOf_1.typeOf(b)) {
        return false;
    }
    if (a == null || b == null) {
        return false;
    }
    switch (typeA) {
        case 'Arguments':
        case 'Array':
        case 'Object':
            if (typeof a.constructor === 'function' && functionName_1.functionName(a.constructor) === 'Promise') {
                return a === b;
            }
            break;
        case 'Boolean':
        case 'Number':
        case 'String':
            if (!(typeof a === typeof b && Object.is(a.valueOf(), b.valueOf()))) {
                return false;
            }
            break;
        case 'Date':
            if (!Object.is(a.valueOf(), b.valueOf())) {
                return false;
            }
            break;
        case 'Error':
            return a.name === b.name && a.message === b.message;
        case 'RegExp':
            if (!(a.source === b.source &&
                a.global === b.global &&
                a.ignoreCase === b.ignoreCase &&
                a.multiline === b.multiline &&
                a.sticky === b.sticky &&
                a.unicode === b.unicode)) {
                return false;
            }
            break;
    }
    let idx = stackA.length - 1;
    while (idx >= 0) {
        if (stackA[idx] === a) {
            return stackB[idx] === b;
        }
        idx -= 1;
    }
    switch (typeA) {
        case 'Map':
            if (a.size !== b.size) {
                return false;
            }
            return _uniqContentEquals(a.entries(), b.entries(), stackA.concat([a]), stackB.concat([b]));
        case 'Set':
            if (a.size !== b.size) {
                return false;
            }
            return _uniqContentEquals(a.values(), b.values(), stackA.concat([a]), stackB.concat([b]));
        case 'Arguments':
        case 'Array':
        case 'Object':
        case 'Boolean':
        case 'Number':
        case 'String':
        case 'Date':
        case 'Error':
        case 'RegExp':
        case 'Int8Array':
        case 'Uint8Array':
        case 'Uint8ClampedArray':
        case 'Int16Array':
        case 'Uint16Array':
        case 'Int32Array':
        case 'Uint32Array':
        case 'Float32Array':
        case 'Float64Array':
        case 'ArrayBuffer':
            break;
        default:
            // Values of other types are only equal if identical.
            return false;
    }
    const keysA = Object.keys(a);
    if (keysA.length !== Object.keys(b).length) {
        return false;
    }
    const extendedStackA = stackA.concat([a]);
    const extendedStackB = stackB.concat([b]);
    idx = keysA.length - 1;
    while (idx >= 0) {
        const key = keysA[idx];
        if (!(Object.prototype.hasOwnProperty.call(b, key) &&
            equals(b[key], a[key], extendedStackA, extendedStackB))) {
            return false;
        }
        idx -= 1;
    }
    return true;
}
exports.equals = equals;
function _uniqContentEquals(aIterable, bIterable, stackA, stackB) {
    const a = Array.from(aIterable);
    const b = Array.from(bIterable);
    // tslint:disable-next-line:variable-name
    function eq(_a, _b) {
        return equals(_a, _b, stackA.slice(), stackB.slice());
    }
    // if *a* array contains any element that is not included in *b*
    // tslint:disable-next-line:no-shadowed-variable
    return !includesWith_1.includesWith((b, aItem) => !includesWith_1.includesWith(eq, aItem, b), b, a);
}
//# sourceMappingURL=equals.js.map
//# sourceMappingURL=equals.js.map
});
___scope___.file("esm/functionName.js", function(exports, require, module, __filename, __dirname){

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const FUNCTION_NAME_REGEX = /^function\s*([\w$]+)/;
const DEFAULT_MATCH = ['', ''];
/**
 * Returns the name of a function.
 * @name functionName(fn: Function): string
 */
function functionName(fn) {
    if (fn.name) {
        return fn.name;
    }
    const [, name] = String(fn).match(FUNCTION_NAME_REGEX) || DEFAULT_MATCH;
    return name;
}
exports.functionName = functionName;
//# sourceMappingURL=functionName.js.map
//# sourceMappingURL=functionName.js.map
});
___scope___.file("esm/includesWith.js", function(exports, require, module, __filename, __dirname){

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function includesWith(pred, x, list) {
    let idx = 0;
    const len = list.length;
    while (idx < len) {
        if (pred(x, list[idx], idx)) {
            return true;
        }
        idx += 1;
    }
    return false;
}
exports.includesWith = includesWith;
//# sourceMappingURL=includesWith.js.map
//# sourceMappingURL=includesWith.js.map
});
___scope___.file("esm/executionEnvironment.js", function(exports, require, module, __filename, __dirname){

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
// Very loose definition of a browser environment
exports.isBrowser = typeof window !== 'undefined' && typeof document !== 'undefined';
//# sourceMappingURL=executionEnvironment.js.map
//# sourceMappingURL=executionEnvironment.js.map
});
___scope___.file("esm/indexOf.js", function(exports, require, module, __filename, __dirname){

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const equals_1 = require("./equals");
function indexOf(list, a, idx = 0) {
    // Array.prototype.indexOf doesn't exist below IE9
    if (typeof list.indexOf === 'function') {
        switch (typeof a) {
            case 'number':
                let inf;
                let item;
                if (a === 0) {
                    // manually crawl the list to distinguish between +0 and -0
                    inf = 1 / a;
                    while (idx < list.length) {
                        item = list[idx];
                        if (item === 0 && 1 / item === inf) {
                            return idx;
                        }
                        idx += 1;
                    }
                    return -1;
                }
                else if (a !== a) {
                    // NaN
                    while (idx < list.length) {
                        item = list[idx];
                        if (typeof item === 'number' && item !== item) {
                            return idx;
                        }
                        idx += 1;
                    }
                    return -1;
                }
                // non-zero numbers can utilise Set
                return list.indexOf(a, idx);
            // all these types can utilise Set
            case 'string':
            case 'boolean':
            case 'function':
            case 'undefined':
                return list.indexOf(a, idx);
            case 'object':
                if (a === null) {
                    // null can utilise Set
                    return list.indexOf(a, idx);
                }
        }
    }
    while (idx < list.length) {
        if (equals_1.equals(list[idx], a)) {
            return idx;
        }
        idx += 1;
    }
    return -1;
}
exports.indexOf = indexOf;
//# sourceMappingURL=indexOf.js.map
//# sourceMappingURL=indexOf.js.map
});
___scope___.file("esm/mapArrayLike.js", function(exports, require, module, __filename, __dirname){

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function mapArrayLike(fn, functor) {
    let idx = 0;
    const len = functor.length;
    const result = Array(len);
    while (idx < len) {
        result[idx] = fn(functor[idx]);
        idx += 1;
    }
    return result;
}
exports.mapArrayLike = mapArrayLike;
//# sourceMappingURL=mapArrayLike.js.map
//# sourceMappingURL=mapArrayLike.js.map
});
___scope___.file("esm/mapObj.js", function(exports, require, module, __filename, __dirname){

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function mapObj(fn, obj) {
    const newObj = {};
    // tslint:disable-next-line:forin
    for (const key in obj) {
        newObj[key] = fn(key, obj[key]);
    }
    return newObj;
}
exports.mapObj = mapObj;
//# sourceMappingURL=mapObj.js.map
//# sourceMappingURL=mapObj.js.map
});
___scope___.file("esm/pathJoin.js", function(exports, require, module, __filename, __dirname){

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const DUPLICATE_PATH_SEPARATOR_REGEX = /\/{2,}/g;
const PATH_SEPARATOR = `/`;
const isString = (x) => typeof x === 'string';
/**
 *
 * @param paths :: string[] A list of paths to join together
 * @param trailingSlash :: boolean whether or not to append a trailing slash
 */
function pathJoin(paths, trailingSlash = false) {
    const path = `/${paths.filter(isString).join(PATH_SEPARATOR)}`.replace(DUPLICATE_PATH_SEPARATOR_REGEX, PATH_SEPARATOR);
    return !trailingSlash || path[path.length - 1] === '/' ? path : path + '/';
}
exports.pathJoin = pathJoin;
//# sourceMappingURL=pathJoin.js.map
//# sourceMappingURL=pathJoin.js.map
});
___scope___.file("esm/quote.js", function(exports, require, module, __filename, __dirname){

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const STEPS = [
    [/\\/g, '\\\\'],
    [/[\b]/g, '\\b'],
    [/\f/g, '\\f'],
    [/\n/g, '\\n'],
    [/\r/g, '\\r'],
    [/\t/g, '\\t'],
    [/\v/g, '\\v'],
    [/\0/g, '\\0'],
];
const LAST_STEP = [/"/g, '\\"'];
function quote(s) {
    const escaped = STEPS.reduce(applyStep, s);
    return '"' + applyStep(escaped, LAST_STEP) + '"';
}
exports.quote = quote;
function applyStep(str, step) {
    return str.replace(step[0], step[1]);
}
//# sourceMappingURL=quote.js.map
//# sourceMappingURL=quote.js.map
});
___scope___.file("esm/toString.js", function(exports, require, module, __filename, __dirname){

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const indexOf_1 = require("./indexOf");
const mapArrayLike_1 = require("./mapArrayLike");
const quote_1 = require("./quote");
/**
 * Convert anything into a string
 * @param x :: any
 * @returns a string representation of a value
 */
exports.toString = (x) => _toString(x, []);
function _toString(x, seen) {
    const recur = (y) => {
        const xs = seen.concat([x]);
        return indexOf_1.indexOf(xs, y) > -1 ? '<Circular>' : _toString(y, xs);
    };
    const mapPairs = (obj, keys) => {
        return mapArrayLike_1.mapArrayLike((k) => {
            return quote_1.quote(k) + ': ' + recur(obj[k]);
        }, keys.slice().sort());
    };
    switch (Object.prototype.toString.call(x)) {
        case '[object Arguments]':
            return '(function() { return arguments; }(' + mapArrayLike_1.mapArrayLike(recur, x).join(', ') + '))';
        case '[object Array]':
            return ('[' +
                mapArrayLike_1.mapArrayLike(recur, x)
                    .concat(mapPairs(x, Object.keys(x).filter(k => !/^\d+$/.test(k))))
                    .join(', ') +
                ']');
        case '[object Boolean]':
            return typeof x === 'object' ? 'new Boolean(' + recur(x.valueOf()) + ')' : x.toString();
        case '[object Date]':
            return ('new Date(' + (isNaN(x.valueOf()) ? recur(NaN) : quote_1.quote(x.toISOString())) + ')');
        case '[object Null]':
            return 'null';
        case '[object Number]':
            return typeof x === 'object'
                ? 'new Number(' + recur(x.valueOf()) + ')'
                : 1 / x === -Infinity
                    ? '-0'
                    : x.toString(10);
        case '[object String]':
            return typeof x === 'object' ? 'new String(' + recur(x.valueOf()) + ')' : quote_1.quote(x);
        case '[object Undefined]':
            return 'undefined';
        default:
            if (typeof x.toString === 'function') {
                const repr = x.toString();
                if (repr !== '[object Object]') {
                    return repr;
                }
            }
            return '{' + mapPairs(x, Object.keys(x)).join(', ') + '}';
    }
}
//# sourceMappingURL=toString.js.map
//# sourceMappingURL=toString.js.map
});
return ___scope___.entry = "esm/index.js";
});
FuseBox.pkg("tslib", {}, function(___scope___){
___scope___.file("tslib.es6.js", function(exports, require, module, __filename, __dirname){

"use strict";
/*! *****************************************************************************
Copyright (c) Microsoft Corporation. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at http://www.apache.org/licenses/LICENSE-2.0

THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
MERCHANTABLITY OR NON-INFRINGEMENT.

See the Apache Version 2.0 License for specific language governing permissions
and limitations under the License.
***************************************************************************** */
/* global Reflect, Promise */
Object.defineProperty(exports, "__esModule", { value: true });
var extendStatics = function (d, b) {
    extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b)
            if (b.hasOwnProperty(p))
                d[p] = b[p]; };
    return extendStatics(d, b);
};
function __extends(d, b) {
    extendStatics(d, b);
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
}
exports.__extends = __extends;
exports.__assign = function () {
    exports.__assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s)
                if (Object.prototype.hasOwnProperty.call(s, p))
                    t[p] = s[p];
        }
        return t;
    };
    return exports.__assign.apply(this, arguments);
};
function __rest(s, e) {
    var t = {};
    for (var p in s)
        if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
            t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
}
exports.__rest = __rest;
function __decorate(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}
exports.__decorate = __decorate;
function __param(paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); };
}
exports.__param = __param;
function __metadata(metadataKey, metadataValue) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
        return Reflect.metadata(metadataKey, metadataValue);
}
exports.__metadata = __metadata;
function __awaiter(thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try {
            step(generator.next(value));
        }
        catch (e) {
            reject(e);
        } }
        function rejected(value) { try {
            step(generator["throw"](value));
        }
        catch (e) {
            reject(e);
        } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
}
exports.__awaiter = __awaiter;
function __generator(thisArg, body) {
    var _ = { label: 0, sent: function () { if (t[0] & 1)
            throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function () { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f)
            throw new TypeError("Generator is already executing.");
        while (_)
            try {
                if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done)
                    return t;
                if (y = 0, t)
                    op = [op[0] & 2, t.value];
                switch (op[0]) {
                    case 0:
                    case 1:
                        t = op;
                        break;
                    case 4:
                        _.label++;
                        return { value: op[1], done: false };
                    case 5:
                        _.label++;
                        y = op[1];
                        op = [0];
                        continue;
                    case 7:
                        op = _.ops.pop();
                        _.trys.pop();
                        continue;
                    default:
                        if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) {
                            _ = 0;
                            continue;
                        }
                        if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) {
                            _.label = op[1];
                            break;
                        }
                        if (op[0] === 6 && _.label < t[1]) {
                            _.label = t[1];
                            t = op;
                            break;
                        }
                        if (t && _.label < t[2]) {
                            _.label = t[2];
                            _.ops.push(op);
                            break;
                        }
                        if (t[2])
                            _.ops.pop();
                        _.trys.pop();
                        continue;
                }
                op = body.call(thisArg, _);
            }
            catch (e) {
                op = [6, e];
                y = 0;
            }
            finally {
                f = t = 0;
            }
        if (op[0] & 5)
            throw op[1];
        return { value: op[0] ? op[1] : void 0, done: true };
    }
}
exports.__generator = __generator;
function __exportStar(m, exports) {
    for (var p in m)
        if (!exports.hasOwnProperty(p))
            exports[p] = m[p];
}
exports.__exportStar = __exportStar;
function __values(o) {
    var m = typeof Symbol === "function" && o[Symbol.iterator], i = 0;
    if (m)
        return m.call(o);
    return {
        next: function () {
            if (o && i >= o.length)
                o = void 0;
            return { value: o && o[i++], done: !o };
        }
    };
}
exports.__values = __values;
function __read(o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m)
        return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
            ar.push(r.value);
    }
    catch (error) {
        e = { error: error };
    }
    finally {
        try {
            if (r && !r.done && (m = i["return"]))
                m.call(i);
        }
        finally {
            if (e)
                throw e.error;
        }
    }
    return ar;
}
exports.__read = __read;
function __spread() {
    for (var ar = [], i = 0; i < arguments.length; i++)
        ar = ar.concat(__read(arguments[i]));
    return ar;
}
exports.__spread = __spread;
function __spreadArrays() {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++)
        s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
}
exports.__spreadArrays = __spreadArrays;
;
function __await(v) {
    return this instanceof __await ? (this.v = v, this) : new __await(v);
}
exports.__await = __await;
function __asyncGenerator(thisArg, _arguments, generator) {
    if (!Symbol.asyncIterator)
        throw new TypeError("Symbol.asyncIterator is not defined.");
    var g = generator.apply(thisArg, _arguments || []), i, q = [];
    return i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i;
    function verb(n) { if (g[n])
        i[n] = function (v) { return new Promise(function (a, b) { q.push([n, v, a, b]) > 1 || resume(n, v); }); }; }
    function resume(n, v) { try {
        step(g[n](v));
    }
    catch (e) {
        settle(q[0][3], e);
    } }
    function step(r) { r.value instanceof __await ? Promise.resolve(r.value.v).then(fulfill, reject) : settle(q[0][2], r); }
    function fulfill(value) { resume("next", value); }
    function reject(value) { resume("throw", value); }
    function settle(f, v) { if (f(v), q.shift(), q.length)
        resume(q[0][0], q[0][1]); }
}
exports.__asyncGenerator = __asyncGenerator;
function __asyncDelegator(o) {
    var i, p;
    return i = {}, verb("next"), verb("throw", function (e) { throw e; }), verb("return"), i[Symbol.iterator] = function () { return this; }, i;
    function verb(n, f) { i[n] = o[n] ? function (v) { return (p = !p) ? { value: __await(o[n](v)), done: n === "return" } : f ? f(v) : v; } : f; }
}
exports.__asyncDelegator = __asyncDelegator;
function __asyncValues(o) {
    if (!Symbol.asyncIterator)
        throw new TypeError("Symbol.asyncIterator is not defined.");
    var m = o[Symbol.asyncIterator], i;
    return m ? m.call(o) : (o = typeof __values === "function" ? __values(o) : o[Symbol.iterator](), i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i);
    function verb(n) { i[n] = o[n] && function (v) { return new Promise(function (resolve, reject) { v = o[n](v), settle(resolve, reject, v.done, v.value); }); }; }
    function settle(resolve, reject, d, v) { Promise.resolve(v).then(function (v) { resolve({ value: v, done: d }); }, reject); }
}
exports.__asyncValues = __asyncValues;
function __makeTemplateObject(cooked, raw) {
    if (Object.defineProperty) {
        Object.defineProperty(cooked, "raw", { value: raw });
    }
    else {
        cooked.raw = raw;
    }
    return cooked;
}
exports.__makeTemplateObject = __makeTemplateObject;
;
function __importStar(mod) {
    if (mod && mod.__esModule)
        return mod;
    var result = {};
    if (mod != null)
        for (var k in mod)
            if (Object.hasOwnProperty.call(mod, k))
                result[k] = mod[k];
    result.default = mod;
    return result;
}
exports.__importStar = __importStar;
function __importDefault(mod) {
    return (mod && mod.__esModule) ? mod : { default: mod };
}
exports.__importDefault = __importDefault;
//# sourceMappingURL=tslib.es6.js.map
});
return ___scope___.entry = "tslib.es6.js";
});
FuseBox.expose([{"alias":"typedLambda","pkg":"default"}]);

FuseBox.import("Lambda/source/index.js");
FuseBox.main("Lambda/source/index.js");
FuseBox.defaultPackageName = "Lambda";
})
(function(e){function r(e){var r=e.charCodeAt(0),n=e.charCodeAt(1);if((m||58!==n)&&(r>=97&&r<=122||64===r)){if(64===r){var t=e.split("/"),i=t.splice(2,t.length).join("/");return[t[0]+"/"+t[1],i||void 0]}var o=e.indexOf("/");if(o===-1)return[e];var a=e.substring(0,o),f=e.substring(o+1);return[a,f]}}function n(e){return e.substring(0,e.lastIndexOf("/"))||"./"}function t(){for(var e=[],r=0;r<arguments.length;r++)e[r]=arguments[r];for(var n=[],t=0,i=arguments.length;t<i;t++)n=n.concat(arguments[t].split("/"));for(var o=[],t=0,i=n.length;t<i;t++){var a=n[t];a&&"."!==a&&(".."===a?o.pop():o.push(a))}return""===n[0]&&o.unshift(""),o.join("/")||(o.length?"/":".")}function i(e){var r=e.match(/\.(\w{1,})$/);return r&&r[1]?e:e+".js"}function o(e){if(m){var r,n=document,t=n.getElementsByTagName("head")[0];/\.css$/.test(e)?(r=n.createElement("link"),r.rel="stylesheet",r.type="text/css",r.href=e):(r=n.createElement("script"),r.type="text/javascript",r.src=e,r.async=!0),t.insertBefore(r,t.firstChild)}}function a(e,r){for(var n in e)e.hasOwnProperty(n)&&r(n,e[n])}function f(e){return{server:require(e)}}function u(e,n){var o=n.path||"./",a=n.pkg||"default",u=r(e);if(u&&(o="./",a=u[0],n.v&&n.v[a]&&(a=a+"@"+n.v[a]),e=u[1]),e)if(126===e.charCodeAt(0))e=e.slice(2,e.length),o="./";else if(!m&&(47===e.charCodeAt(0)||58===e.charCodeAt(1)))return f(e);var s=x[a];if(!s){if(m&&"electron"!==_.target)throw"Package not found "+a;return f(a+(e?"/"+e:""))}e=e?e:"./"+s.s.entry;var l,d=t(o,e),c=i(d),p=s.f[c];return!p&&c.indexOf("*")>-1&&(l=c),p||l||(c=t(d,"/","index.js"),p=s.f[c],p||"."!==d||(c=s.s&&s.s.entry||"index.js",p=s.f[c]),p||(c=d+".js",p=s.f[c]),p||(p=s.f[d+".jsx"]),p||(c=d+"/index.jsx",p=s.f[c])),{file:p,wildcard:l,pkgName:a,versions:s.v,filePath:d,validPath:c}}function s(e,r,n){if(void 0===n&&(n={}),!m)return r(/\.(js|json)$/.test(e)?h.require(e):"");if(n&&n.ajaxed===e)return console.error(e,"does not provide a module");var i=new XMLHttpRequest;i.onreadystatechange=function(){if(4==i.readyState)if(200==i.status){var n=i.getResponseHeader("Content-Type"),o=i.responseText;/json/.test(n)?o="module.exports = "+o:/javascript/.test(n)||(o="module.exports = "+JSON.stringify(o));var a=t("./",e);_.dynamic(a,o),r(_.import(e,{ajaxed:e}))}else console.error(e,"not found on request"),r(void 0)},i.open("GET",e,!0),i.send()}function l(e,r){var n=y[e];if(n)for(var t in n){var i=n[t].apply(null,r);if(i===!1)return!1}}function d(e){if(null!==e&&["function","object","array"].indexOf(typeof e)!==-1&&!e.hasOwnProperty("default"))return Object.isFrozen(e)?void(e.default=e):void Object.defineProperty(e,"default",{value:e,writable:!0,enumerable:!1})}function c(e,r){if(void 0===r&&(r={}),58===e.charCodeAt(4)||58===e.charCodeAt(5))return o(e);var t=u(e,r);if(t.server)return t.server;var i=t.file;if(t.wildcard){var a=new RegExp(t.wildcard.replace(/\*/g,"@").replace(/[.?*+^$[\]\\(){}|-]/g,"\\$&").replace(/@@/g,".*").replace(/@/g,"[a-z0-9$_-]+"),"i"),f=x[t.pkgName];if(f){var p={};for(var v in f.f)a.test(v)&&(p[v]=c(t.pkgName+"/"+v));return p}}if(!i){var g="function"==typeof r,y=l("async",[e,r]);if(y===!1)return;return s(e,function(e){return g?r(e):null},r)}var w=t.pkgName;if(i.locals&&i.locals.module)return i.locals.module.exports;var b=i.locals={},j=n(t.validPath);b.exports={},b.module={exports:b.exports},b.require=function(e,r){var n=c(e,{pkg:w,path:j,v:t.versions});return _.sdep&&d(n),n},m||!h.require.main?b.require.main={filename:"./",paths:[]}:b.require.main=h.require.main;var k=[b.module.exports,b.require,b.module,t.validPath,j,w];return l("before-import",k),i.fn.apply(k[0],k),l("after-import",k),b.module.exports}if(e.FuseBox)return e.FuseBox;var p="undefined"!=typeof ServiceWorkerGlobalScope,v="undefined"!=typeof WorkerGlobalScope,m="undefined"!=typeof window&&"undefined"!=typeof window.navigator||v||p,h=m?v||p?{}:window:global;m&&(h.global=v||p?{}:window),e=m&&"undefined"==typeof __fbx__dnm__?e:module.exports;var g=m?v||p?{}:window.__fsbx__=window.__fsbx__||{}:h.$fsbx=h.$fsbx||{};m||(h.require=require);var x=g.p=g.p||{},y=g.e=g.e||{},_=function(){function r(){}return r.global=function(e,r){return void 0===r?h[e]:void(h[e]=r)},r.import=function(e,r){return c(e,r)},r.on=function(e,r){y[e]=y[e]||[],y[e].push(r)},r.exists=function(e){try{var r=u(e,{});return void 0!==r.file}catch(e){return!1}},r.remove=function(e){var r=u(e,{}),n=x[r.pkgName];n&&n.f[r.validPath]&&delete n.f[r.validPath]},r.main=function(e){return this.mainFile=e,r.import(e,{})},r.expose=function(r){var n=function(n){var t=r[n].alias,i=c(r[n].pkg);"*"===t?a(i,function(r,n){return e[r]=n}):"object"==typeof t?a(t,function(r,n){return e[n]=i[r]}):e[t]=i};for(var t in r)n(t)},r.dynamic=function(r,n,t){this.pkg(t&&t.pkg||"default",{},function(t){t.file(r,function(r,t,i,o,a){var f=new Function("__fbx__dnm__","exports","require","module","__filename","__dirname","__root__",n);f(!0,r,t,i,o,a,e)})})},r.flush=function(e){var r=x.default;for(var n in r.f)e&&!e(n)||delete r.f[n].locals},r.pkg=function(e,r,n){if(x[e])return n(x[e].s);var t=x[e]={};return t.f={},t.v=r,t.s={file:function(e,r){return t.f[e]={fn:r}}},n(t.s)},r.addPlugin=function(e){this.plugins.push(e)},r.packages=x,r.isBrowser=m,r.isServer=!m,r.plugins=[],r}();return m||(h.FuseBox=_),e.FuseBox=_}(this))
//# sourceMappingURL=index.js.map?tm=1561946656616